@@ -80,6 +80,7 @@ typedef enum {
 	/* Devices */
 	BVW_ERROR_DVD_ENCRYPTED,
 	BVW_ERROR_INVALID_DEVICE,
+	BVW_ERROR_DEVICE_BUSY,
 	/* Network */
 	BVW_ERROR_UNKNOWN_HOST,
 	BVW_ERROR_NETWORK_UNREACHABLE,
@@ -171,20 +172,10 @@ void bacon_video_widget_set_connection_speed     (BaconVideoWidget *bvw,
 						  int speed);
 int bacon_video_widget_get_connection_speed      (BaconVideoWidget *bvw);
 
-typedef enum {
-	BVW_CAN_PLAY_SUCCESS,
-	BVW_CAN_PLAY_MISSING_CHANNELS,
-	BVW_CAN_PLAY_MISSING_PLUGINS,
-	BVW_CAN_PLAY_UNSUPPORTED
-} BaconVideoWidgetCanPlayStatus;
-
-BaconVideoWidgetCanPlayStatus bacon_video_widget_can_play
-						 (BaconVideoWidget *bvw,
-						  TotemDiscMediaType type);
-
 gchar **bacon_video_widget_get_mrls		 (BaconVideoWidget *bvw,
 						  TotemDiscMediaType type,
-						  const char *device);
+						  const char *device,
+						  GError **error);
 void bacon_video_widget_set_subtitle_font	 (BaconVideoWidget *bvw,
 						  const char *font);
 void bacon_video_widget_set_subtitle_encoding	 (BaconVideoWidget *bvw,
@@ -199,6 +190,7 @@ typedef enum {
 	BVW_INFO_ALBUM,
 	BVW_INFO_DURATION,
 	BVW_INFO_TRACK_NUMBER,
+	BVW_INFO_COVER,
 	/* Video */
 	BVW_INFO_HAS_VIDEO,
 	BVW_INFO_DIMENSION_X,
@@ -252,6 +244,7 @@ typedef enum {
 	BVW_RATIO_DVB = 4
 } BaconVideoWidgetAspectRatio;
 
+gboolean bacon_video_widget_can_deinterlace	 (BaconVideoWidget *bvw);
 void bacon_video_widget_set_deinterlacing        (BaconVideoWidget *bvw,
 						  gboolean deinterlace);
 gboolean bacon_video_widget_get_deinterlacing    (BaconVideoWidget *bvw);
